==> gcloud-oauth-vue-0.1.18.tgz: package/src/store/modules/router.js <==

//同步过滤路由资源
export function filterAsyncRoutes(routes,parentPath,roles,perms) {
  if(roles.includes("administrator")){
     return routes;    
  }
  console.log(routes);
  const res = [];
  routes.forEach(route => {
    const tmp = { ...route };
    let path=route.path.startsWith("/")?route.path:parentPath+route.path;
    let perm = path.split("/").slice(2).join(":");
    console.log(perm);
    if(perms.includes(perm)){
      if (tmp.children) {
          tmp.children = filterAsyncRoutes(tmp.children,path, roles,perms);
      }
      res.push(tmp)
    }
  })
  return res;
}

const state = {
  routers :[],
  addRouters: [],
  moduleRouters:[]
}

const mutations = {
  SET_ROUTERS: (state, routers) => {
    // 保存动态路由用来addRouter
    state.routers = [...state.routers,...routers];
    state.addRouters = routers;
  },
  ADD_MODULE_ROUTERS:(state,moduleRouters) =>{
    state.moduleRouters = [...state.moduleRouters,...moduleRouters] ;
  }
}

const actions = {
  newRoutes({state,commit,rootGetters}) {
    return new Promise(resolve =>{
        let accessedRoutes = [];
        let roles = rootGetters.roles;
        let perms = rootGetters.perms;
        //加载用户模块route
        accessedRoutes = [ ...accessedRoutes , ...filterAsyncRoutes(state.moduleRouters,"",roles,perms)];

        console.log(accessedRoutes);

        commit('SET_ROUTERS', accessedRoutes);
        //console.log(state.routers);
        resolve(accessedRoutes);
    });
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

==> gcloud-oauth-vue-0.3.6.tgz: package/src/store/modules/router.js <==

//同步过滤路由资源
export function filterAsyncRoutes(routes,parentPath,roles,perms) {
  if(roles.includes("administrator")){
     return routes;    
  }
  console.log(routes);
  const res = [];
  routes.forEach(route => {
    const tmp = { ...route };
    let path=route.path.startsWith("/")?route.path:parentPath+"/"+route.path;
    // let perm = path.split("/").slice(2).join(":");
    // console.log(perm)
    // console.log(perms)
    // if(perms.includes(perm)){
      if (tmp.children) {
          tmp.children = filterAsyncRoutes(tmp.children,path, roles,perms);
      }
      res.push(tmp)
    // }
  })
  return res;
}

const state = {
  routers :[],
  addRouters: [],
  moduleRouters:[]
}

const mutations = {
  SET_ROUTERS: (state, routers) => {
    // 保存动态路由用来addRouter
    state.routers = [...state.routers,...routers];
    state.addRouters = routers;
  },
  ADD_MODULE_ROUTERS:(state,moduleRouters) =>{
    state.moduleRouters = [...state.moduleRouters,...moduleRouters] ;
  }
}

const actions = {
  newRoutes({state,commit,rootGetters}) {
    return new Promise(resolve =>{
        let accessedRoutes = [];
        let roles = rootGetters.roles;
        let perms = rootGetters.perms;
        //加载用户模块route
        accessedRoutes = [ ...accessedRoutes , ...filterAsyncRoutes(state.moduleRouters,"",roles,perms)];

        console.log(accessedRoutes);

        commit('SET_ROUTERS', accessedRoutes);
        //console.log(state.routers);
        resolve(accessedRoutes);
    });
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
